==> 0.0.2.tar.gz: lib/src/screens/chat_create_screen.dart <==
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_user/ocg_user.dart';
import 'package:ocg_login/ocg_login.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';

import '../bloc/chat_create/event.dart';
import '../bloc/chat_create/state.dart';
import '../bloc/chat_create/bloc.dart';
import '../models/chat.dart';

class ChatCreateScreen extends StatefulWidget {
  ChatCreateScreen({Key key}) : super(key: key);

  @override
  _ChatCreateScreenState createState() => _ChatCreateScreenState();
}

class _ChatCreateScreenState extends State<ChatCreateScreen> {
  Chat chat;

  @override
  void initState() {
    super.initState();
    chat = Chat.named(
      admins: [],
      users: [],
    );
  }

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<LoginBloc, LoginState>(builder: (context, loginState) {
      if (loginState is LoginNotExistState) {
        return Center(
          child: Text("Not Logged In"),
        );
      }
      return BlocListener<ChatCreateBloc, ChatCreateState>(
        listener: (context, state) {
          if (state is ChatCreateSuccessState) {
            Navigator.of(context).pop();
          } else if (state is ChatCreateErrorState) {
            AppUIHelper.of(context).showErrorDialog(state.error);
          }
        },
        child: BlocBuilder<ChatCreateBloc, ChatCreateState>(
            builder: (context, chatCreateState) {
          return ModalProgressHUD(
            inAsyncCall: chatCreateState is ChatCreateLoadingState,
            child: Scaffold(
              appBar: AppBar(
                title: Text("Create Chat"),
                brightness: Brightness.light,
              ),
              body: SingleChildScrollView(
                child: Padding(
                  padding:
                      const EdgeInsets.symmetric(vertical: 12, horizontal: 16),
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      TextFormField(
                        decoration: InputDecoration(hintText: "Enter name"),
                        onChanged: (String value) {
                          chat = chat.copyWith(groupName: value);
                          if (mounted) setState(() {});
                        },
                      ),
                      SizedBox(
                        height: 18,
                      ),
                      UserSelectWidget(
                        onChanged: (users) {
                          chat = chat.copyWith(
                              users: users.map((e) => e.id).toList());
                          setState(() {});
                        },
                      )
                    ],
                  ),
                ),
              ),
              bottomNavigationBar: Padding(
                padding: const EdgeInsets.all(8.0),
                child: CupertinoButton(
                    child: Text("Continue"),
                    onPressed: () {
                      BlocProvider.of<ChatCreateBloc>(context).add(
                          ChatCreateStartEvent(chat.copyWith(isGroup: true)));
                    },
                    color: CupertinoColors.activeBlue),
              ),
            ),
          );
        }),
      );
    });
  }
}

==> 0.0.19.tar.gz: lib/src/screens/chat_create_screen.dart <==
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_user/ocg_user.dart';
import 'package:ocg_login/ocg_login.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';

import '../bloc/chat_create/event.dart';
import '../bloc/chat_create/state.dart';
import '../bloc/chat_create/bloc.dart';
import '../models/chat.dart';

class ChatCreateScreen extends StatefulWidget {
  ChatCreateScreen({Key key}) : super(key: key);

  @override
  _ChatCreateScreenState createState() => _ChatCreateScreenState();
}

class _ChatCreateScreenState extends State<ChatCreateScreen> {
  Chat chat;

  @override
  void initState() {
    super.initState();
    chat = Chat.named(
      admins: [],
      users: [],
    );
  }

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<LoginBloc, LoginState>(builder: (context, loginState) {
      if (loginState is LoginNotExistState) {
        return Center(
          child: Text("Not Logged In"),
        );
      }
      return BlocListener<ChatCreateBloc, ChatCreateState>(
        listener: (context, state) {
          if (state is ChatCreateSuccessState) {
            Navigator.of(context).pop();
          } else if (state is ChatCreateErrorState) {
            AppUIHelper.of(context).showErrorDialog(state.error);
          }
        },
        child: BlocBuilder<ChatCreateBloc, ChatCreateState>(
            builder: (context, chatCreateState) {
          return ModalProgressHUD(
            inAsyncCall: chatCreateState is ChatCreateLoadingState,
            child: Scaffold(
              appBar: AppBar(
                title: Text("Create Chat"),
                brightness: Brightness.light,
              ),
              body: SingleChildScrollView(
                child: Padding(
                  padding:
                      const EdgeInsets.symmetric(vertical: 12, horizontal: 16),
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      TextFormField(
                        decoration: InputDecoration(hintText: "Enter name"),
                        onChanged: (String value) {
                          chat = chat.copyWith(groupName: value);
                          if (mounted) setState(() {});
                        },
                      ),
                      SizedBox(
                        height: 18,
                      ),
                      UserSelectWidget(
                        onChanged: (users) {
                          chat = chat.copyWith(
                              users: users.map((e) => e.id).toList());
                          setState(() {});
                        },
                      )
                    ],
                  ),
                ),
              ),
              bottomNavigationBar: Padding(
                padding: const EdgeInsets.all(8.0),
                child: CupertinoButton(
                    child: Text("Continue"),
                    onPressed: () {
                      BlocProvider.of<ChatCreateBloc>(context).add(
                          ChatCreateStartEvent(chat.copyWith(
                              isGroup: true, metadata: {"created": true})));
                    },
                    color: CupertinoColors.activeBlue),
              ),
            ),
          );
        }),
      );
    });
  }
}
